vica package
============

Submodules
----------

vica\.get\_features module
--------------------------

.. automodule:: vica.get_features
    :members:
    :undoc-members:
    :show-inheritance:

vica\.khmer\_features module
----------------------------

.. automodule:: vica.khmer_features
    :members:
    :undoc-members:
    :show-inheritance:

vica\.minhash module
--------------------

.. automodule:: vica.minhash
    :members:
    :undoc-members:
    :show-inheritance:

vica\.prodigal module
---------------------

.. automodule:: vica.prodigal
    :members:
    :undoc-members:
    :show-inheritance:

vica\.split\_shred module
-------------------------

.. automodule:: vica.split_shred
    :members:
    :undoc-members:
    :show-inheritance:

vica\.tfrecord\_maker module
----------------------------

.. automodule:: vica.tfrecord_maker
    :members:
    :undoc-members:
    :show-inheritance:

vica\.train\_eval module
------------------------

.. automodule:: vica.train_eval
    :members:
    :undoc-members:
    :show-inheritance:

vica\.vica\_cli module
----------------------

.. automodule:: vica.vica_cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vica
    :members:
    :undoc-members:
    :show-inheritance:
